package com.aitrainer.api.controller

import com.aitrainer.api.model.CustomerTrainingPlan
import com.aitrainer.api.model.CustomerTrainingPlanExercise
import com.aitrainer.api.repository.CustomerTrainingPlanRepository
import org.slf4j.LoggerFactory
import org.springframework.http.ResponseEntity
import org.springframework.security.access.annotation.Secured
import org.springframework.web.bind.annotation.*
import javax.validation.Valid

@RestController
@RequestMapping("/api")
class CustomerTrainingPlanController(private val customerTrainingPlanRepository: CustomerTrainingPlanRepository) {
    private val logger = LoggerFactory.getLogger(javaClass)

    @PostMapping("/customer_training_plan")
    fun createNewCustomerTrainingPlan(@Valid @RequestBody customerTrainingPlan: CustomerTrainingPlan): ResponseEntity<CustomerTrainingPlan> {
        logger.info("Create customer training plan: $customerTrainingPlan")
        return ResponseEntity.ok().body(customerTrainingPlanRepository.save(customerTrainingPlan))
    }

    @Secured
    @PostMapping("customer_training_plan/update/{id}")
    fun updateCustomerProperty(@PathVariable(value = "id") trainingPlanId: Long,
                               @Valid @RequestBody customerTrainingPlanToUpdate: CustomerTrainingPlan): ResponseEntity<CustomerTrainingPlan> {
        val customerTrainingPlan = customerTrainingPlanRepository.findById(trainingPlanId).orElse(null)
            ?: return ResponseEntity.notFound().build()

        val updatedCustomerTrainingPlan = customerTrainingPlan.copy(
            trainingPlanId = customerTrainingPlanToUpdate.trainingPlanId,
            customerId = customerTrainingPlanToUpdate.customerId,
            dateAdd = customerTrainingPlanToUpdate.dateAdd
        )
        return ResponseEntity.ok().body(customerTrainingPlanRepository.save(updatedCustomerTrainingPlan))
    }
}