package com.aitrainer.api.controller.diet

import com.aitrainer.api.model.Customer
import com.aitrainer.api.model.CustomerMembership
import com.aitrainer.api.model.CustomerPropertyProperty
import com.aitrainer.api.model.diet.DietCustomer
import com.aitrainer.api.model.diet.DietUser
import com.aitrainer.api.repository.CustomerRepository
import com.aitrainer.api.repository.diet.DietUserRepository
import com.aitrainer.api.service.Firebase
import com.aitrainer.api.service.ServiceBeans
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.beans.factory.annotation.Value
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*
import java.time.LocalDateTime
import java.time.format.DateTimeFormatter
import java.util.*

@RestController
@RequestMapping("/api")
class DietCustomerController(private val dietUserRepository: DietUserRepository, private val customerRepository: CustomerRepository) {

    @Autowired
    var serviceBeans: ServiceBeans? = null

    @PostMapping("/diet_registration")
    fun insert(@RequestBody dietCustomerJson: String, @Value("\${firebase.key}") apiKey: String): ResponseEntity<*> {
        val newDietCustomer: DietCustomer = DietCustomer().fromJson(dietCustomerJson)

        if ( newDietCustomer.email.isEmpty()) {
            return ResponseEntity.badRequest().body("No Email")
        }

        val current = LocalDateTime.now()
        val formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss.SSS")
        val nowFormatted = current.format(formatter)

        val stringCharacters = ('0'..'z').toList().toTypedArray()
        val genPassword = (1..10).map { stringCharacters.random() }.joinToString("")

        val idToken: String?

        var existingCustomer: Customer? = customerRepository.findByEmailAndActive(newDietCustomer.email, "Y")

        if (existingCustomer == null ) {
            val firebase = Firebase(apiKey)
            val signupResponse = firebase.signUp(newDietCustomer.email, genPassword)
                ?: return ResponseEntity.badRequest().body("Firebase exception ${firebase.error}")
            idToken = signupResponse.idToken

            val savingCustomer = Customer()

            if ( serviceBeans == null ) {
                serviceBeans = ServiceBeans()
            }
            with (savingCustomer) {
                email = newDietCustomer.email
                password = serviceBeans!!.passwordEncoder().encode(genPassword)
                firebaseRegToken = signupResponse.idToken
                firebaseUid = signupResponse.localId
                dateAdd = nowFormatted
                firstname = newDietCustomer.firstname
                name = ""
                goal = newDietCustomer.goal
                fitnessLevel = newDietCustomer.fitnessLevel
                birthYear = newDietCustomer.birthYear
                sex = newDietCustomer.sex
            }

            val newCustomer = customerRepository.save(savingCustomer)

            if ( newDietCustomer.weight != 0.0 ) {
                val property = CustomerPropertyProperty()
                with (property) {
                    propertyId = 1
                    propertyValue = newDietCustomer.weight
                    dateAdd= nowFormatted
                    goal = false
                    customer = newCustomer
                }
                newCustomer.properties.add(property)
            }
            if ( newDietCustomer.height != 0.0 ) {
                val property = CustomerPropertyProperty()
                with (property) {
                    propertyId = 2
                    propertyValue = newDietCustomer.height
                    dateAdd = nowFormatted
                    goal = false
                    customer = newCustomer
                }
                newCustomer.properties.add(property)
            }

            val newMembershipId = newDietCustomer.membershipId
            if ( newMembershipId != 0L) {
                val membership = CustomerMembership()
                with(membership) {
                    customer = newCustomer
                    membershipId = newMembershipId
                    startDate = nowFormatted
                }
                newCustomer.memberships.add(membership)
            }

            customerRepository.save(newCustomer)
            existingCustomer = newCustomer
        } else {
            val existingDietUser = dietUserRepository.findByCustomerId(existingCustomer.customerId)
            if ( existingDietUser != null ) {
                return ResponseEntity.badRequest().body("DietCustomer exists")
            } else {
                val newDietUser = DietUser(
                    customerId = existingCustomer.customerId
                )
                dietUserRepository.save(newDietUser)

            }
            idToken = existingCustomer.firebaseRegToken!!
        }

        // create email link
        /*val activationLink = "https://diet4you.andio.hu/welcome/id=$idToken"
        if ( emailTemplateService == null ) {
            emailTemplateService = EmailTemplateService()
        }
        val html = emailTemplateService!!.getEmailBody(newDietCustomer.firstname, activationLink, "diet_registration_email")
        val subject = emailTemplateService!!.getSubjectDiet()

        // send email
        val email = Email()
        email.send(newDietCustomer.email, html, subject)*/

        return ResponseEntity.ok().body(existingCustomer)
    }

}