package com.aitrainer.api.controller.diet

import com.aitrainer.api.model.diet.Meal
import com.aitrainer.api.repository.diet.MealRepository
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

@RestController
@RequestMapping("api")
class MealController(private val mealRepository: MealRepository) {

    @PostMapping ("/meal")
    fun insert(@RequestBody meal: Meal): ResponseEntity<Meal> {
        val newMeal = mealRepository.save(meal)
        return ResponseEntity.ok().body(newMeal)
    }

    @GetMapping("/meal")
    fun getAll(): ResponseEntity<List<Meal>> {
        val list = mealRepository.findAll()
        return if (list.isEmpty()) ResponseEntity.notFound().build() else
            ResponseEntity.ok().body(list)
    }

    @GetMapping("/meal/{id}")
    fun getById(@PathVariable id: Long): ResponseEntity<Meal> {
        val rawMaterial = mealRepository.findById(id)
        return if (rawMaterial == null) ResponseEntity.notFound().build() else
            ResponseEntity.ok().body(rawMaterial)
    }

    @GetMapping("/meal/by_name/{name}")
    fun getByName(@PathVariable name: String): ResponseEntity<Meal> {
        val meal = mealRepository.findByName(name)
        return if (meal == null) ResponseEntity.notFound().build() else
            ResponseEntity.ok().body(meal)
    }

}