package com.aitrainer.api.test

import com.aitrainer.api.controller.ExerciseTypeController
import com.aitrainer.api.model.ExerciseType
import com.aitrainer.api.repository.ExerciseTypeRepository
import org.junit.jupiter.api.Test
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.ResponseEntity
import kotlin.test.assertEquals

@SpringBootTest
class ExerciseTypeTest {
    private val logger = LoggerFactory.getLogger(javaClass)

    @Autowired
    private lateinit var exerciseTypeRepository: ExerciseTypeRepository
    private var insertedId: Long = 0

    @Test
    fun testGet() {
        var id: Long = 7
        var extype: ExerciseType = exerciseTypeRepository.findById(id).orElse(null)
        assertEquals(extype.name, "4x10m-es ingafutás")

        id = 38
        extype = exerciseTypeRepository.findById(id).orElse(null)
        assertEquals(extype.name, "Pull Ups")
        assertEquals(extype.unit, "repeat")

        id = 37
        extype = exerciseTypeRepository.findById(id).orElse(null)
        assertEquals(extype.name, "Chest Press")
        assertEquals(extype.unit, "repeat")
        assertEquals(extype.unitQuantityUnit, "kilogram")
    }

    @Test
    fun testGetAll() {
        val exerciseTypes: List<ExerciseType> = exerciseTypeRepository.findAll()
        assertEquals(exerciseTypes[0].exerciseTypeId, 1)
        assertEquals(exerciseTypes[0].name, "Melső fekvőtámasz 1 perc")

        assertEquals(exerciseTypes[15].name, "Sit-ups")
        assertEquals(exerciseTypes[15].unit, "repeat")
        assertEquals(exerciseTypes[20].unitQuantityUnit, "kilogram")
        assertEquals(exerciseTypes[15].alternatives.size, 0)
        assertEquals(exerciseTypes[15].parents.size, 1)
    }

    @Test
    fun testInsert(){
        logger.info("Add 'Húzodszkodás 2")
        val newEx = ExerciseType( "Húzodszkodás 2", " A legtöbb húzodszkodást 24 óra alatt John Ort érte el 7600-al 2016-ban. ", null, null, null ,true, false)
        val savedEx: ExerciseType = exerciseTypeRepository.save(newEx)
        assertEquals(savedEx.name, "Húzodszkodás 2")

        this.insertedId = savedEx.exerciseTypeId

        logger.info("Find 'Húzodszkodás 2")
        val extype: ExerciseType = exerciseTypeRepository.findById( savedEx.exerciseTypeId ).orElse(null)
        assertEquals( extype.name, "Húzodszkodás 2")

        logger.info("Delete 'Húzodszkodás 2")
        exerciseTypeRepository.delete(extype)
    }
}