package com.aitrainer.api.test.diet

import com.aitrainer.api.model.diet.DietUserSensitivity
import com.aitrainer.api.test.Tokenizer
import com.google.gson.Gson
import org.junit.jupiter.api.BeforeAll
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.TestInstance
import org.junit.jupiter.api.extension.ExtendWith
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.MediaType
import org.springframework.test.context.junit.jupiter.SpringExtension
import org.springframework.test.web.servlet.MockMvc
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get
import org.springframework.test.web.servlet.result.MockMvcResultMatchers.*


@ExtendWith(SpringExtension::class)
@SpringBootTest
@AutoConfigureMockMvc
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class DietUserSensitivityTest {

    @Autowired
    private lateinit var mockMvc: MockMvc

    private val dietUserSensitivity = DietUserSensitivity(
        sensitivityId = 1,
        dietUserId = 5,
    )
    private var authToken: String = ""

    @BeforeAll
    fun initTest() {
        authToken = Tokenizer.getToken()
    }


    @Test
    fun `insert dietUserSensitivity successfully`() {

        mockMvc.perform(
            MockMvcRequestBuilders.post("/api/diet_user_sensitivity")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(toJson(dietUserSensitivity))
        )
        .andExpect(status().isOk)
        .andExpect(jsonPath("$.dietUserId").value(5))
        .andExpect(jsonPath("$.sensitivityId").value(1))

        // Act & Assert
        mockMvc.perform(get("/api/diet_user_sensitivity/{dietUserId}", 5)
            .header("Authorization", "Bearer $authToken")
            .contentType(MediaType.APPLICATION_JSON))
            .andExpect(status().isOk)
            .andExpect(jsonPath("$.[0].dietUserId").value(5))
            .andExpect(jsonPath("$.[0].sensitivityId").value(1))


    }

    private fun toJson(obj: Any): String {
        return Gson().toJson(obj)
    }
}
