package com.aitrainer.api.test.diet

import com.aitrainer.api.model.diet.DietUser
import com.aitrainer.api.test.Tokenizer
import com.google.gson.Gson
import org.junit.jupiter.api.BeforeAll
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.TestInstance
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.MediaType
import org.springframework.test.web.servlet.MockMvc
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders.post
import org.springframework.test.web.servlet.result.MockMvcResultMatchers.*

@SpringBootTest
@AutoConfigureMockMvc
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class DietUserTest {

    @Autowired
    lateinit var mockMvc: MockMvc

    private var authToken: String? = ""

    @BeforeAll
    fun initTest() {
        authToken = Tokenizer.getToken()
    }

    @Test
    fun `insert diet user successfully`() {
        val dietUser = DietUser(1, customerId = 1)
        val gson = Gson()

        mockMvc.perform(
            post("/api/diet_user")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(gson.toJson(dietUser))
        )
            .andExpect(status().isOk)
            .andExpect(jsonPath("$.customerId").value(1))


        mockMvc.perform(get("/api/diet_user/${dietUser.dietUserId}")
            .header("Authorization", "Bearer $authToken")
            .contentType(MediaType.APPLICATION_JSON))
            .andExpect(status().isOk)
            .andExpect(jsonPath("$.customerId").value(1))
    }

}
