package com.aitrainer.api.test.openai

import com.aitrainer.api.model.OpenAI
import com.aitrainer.api.test.Tokenizer
import com.google.gson.Gson
import org.junit.jupiter.api.BeforeAll
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.TestInstance
import org.junit.jupiter.api.extension.ExtendWith
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.MediaType
import org.springframework.test.context.junit.jupiter.SpringExtension
import org.springframework.test.web.servlet.MockMvc
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders
import org.springframework.test.web.servlet.result.MockMvcResultMatchers


@ExtendWith(SpringExtension::class)
@SpringBootTest
@AutoConfigureMockMvc
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class OpenAITest {

    @Autowired
    private lateinit var mockMvc: MockMvc

    private var authToken: String? = ""

    @BeforeAll
    fun initTest() {
        authToken = Tokenizer.getToken()
    }


   /* @Test
    fun `get a question successfully`() {
        val question = "Who the f. is Alice?"

        mockMvc.perform(
            MockMvcRequestBuilders.get("/api/openai/completion")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(question)
        )
            .andExpect(MockMvcResultMatchers.status().isOk)
            //.andExpect(MockMvcResultMatchers.content().string("Sorry I dont know"))

    }*/

    @Test
    fun `get a question successfully with model name`() {
        val question = "Who the f. is Alice? Who sing that song?"
        val openai = OpenAI(
            question = question,
            modelName = "text-ada-001",
            temperature = 0.5
        )
        mockMvc.perform(
            MockMvcRequestBuilders.post("/api/openai/completion_with_model")
                .contentType(MediaType.APPLICATION_JSON)
                .header("Authorization", "Bearer $authToken")
                .content(toJson(openai))
        )
            .andExpect(MockMvcResultMatchers.status().isOk)
        //.andExpect(MockMvcResultMatchers.content().string("Sorry I dont know"))

    }

    @Test
    fun `get models  successfully`() {
        mockMvc.perform(
        MockMvcRequestBuilders.get("/api/openai/list_models")
            .contentType(MediaType.APPLICATION_JSON)
            .header("Authorization", "Bearer $authToken")
        )
        .andExpect(MockMvcResultMatchers.status().isOk)
    }

    private fun toJson(obj: Any): String {
        return Gson().toJson(obj)
    }
}